======================
py_auth_amqp_wrapper
======================

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://pypi.org/project/black

Introduction
=============

This Module aims to provide :code:`py_auth_micro` 's Workflows over AMQP so it can be used in an Micro-Service environment.